RequestSourceMode

Enum RequestSourceMode 

pub enum RequestSourceMode {
    OptionalWhenPresent,
    Required,
}
Whether source headers are required or only validated when present.

Variants



OptionalWhenPresent

Accept requests without source headers, but validate them when present.



Required

Require a trusted Origin or Referer header for unsafe cookie-authenticated actions.